Hashtree-backed git object and ref storage with configurable persistence
Stores git objects and refs in a hashtree merkle tree:
root/
.git/
HEAD -> “ref: refs/heads/main”
refs/heads/main ->
The root hash (SHA-256) is the content-addressed identifier for the entire repo state.
Structs
- GitStorage
- Git storage backed by HashTree with configurable persistence
Enums
- Local
Store - Local blob store - wraps either FsBlobStore or LmdbBlobStore